"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCSCustom = void 0;
const AbstractMessage_1 = require("../AbstractMessage");
const enums_1 = require("../../enums");
/**
 * Represents a custom message for RCS.
 *
 * @group RCS
 */
class RCSCustom extends AbstractMessage_1.AbstractMessage {
    /**
     * Sends a custom message through RCS
     *
     * @param {RCSCustomParams} params - The parameters for creating a RCS custom message.
     * @example
     * ```ts
     * import { RCSCustom } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new RCSCustom({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  custom: {
     *    foo: 'bar',
     *  }
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        /**
         * The channel through which the message will be sent. Always `rcs`
         */
        this.channel = enums_1.Channels.RCS;
        /**
         * The type of message. For a custom message, this will always be `custom`.
         */
        this.messageType = 'custom';
        this.custom = params.custom;
        this.ttl = params.ttl;
    }
}
exports.RCSCustom = RCSCustom;
