"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCSText = void 0;
const AbstractTextMessage_1 = require("../AbstractTextMessage");
const enums_1 = require("../../enums");
/**
 * Represents a text message for the RCS channel.
 *
 * @group RCS
 */
class RCSText extends AbstractTextMessage_1.AbstractTextMessage {
    /**
     * Sends a text message through the RCS channel.
     *
     * @param {RCSTextParams} params - The parameters for creating a RCS text message.
     *
     * @example
     * ```ts
     * import { RCSText } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new RCSText({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  text: 'Hello world',
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        /**
         * The channel for this message (always 'rcs').
         */
        this.channel = enums_1.Channels.RCS;
        this.ttl = params.ttl;
    }
}
exports.RCSText = RCSText;
