"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCSVideo = void 0;
const __1 = require("../");
const enums_1 = require("../../enums");
/**
 * Represents an video message for the RCS channel.
 *
 * @group RCS
 */
class RCSVideo extends __1.AbstractVideoMessage {
    /**
     * Send an RCS video message.
     *
     * @param {RCSVideoParams} params - The parameters for creating the video message.
     *
     * @example
     * ```ts
     * import { RCSVideo } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new RCSVideo({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  audio: {
     *    url: 'https://example.com/video.mp4',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = enums_1.Channels.RCS;
        this.ttl = params?.ttl;
    }
}
exports.RCSVideo = RCSVideo;
